@@ -261,6 +261,15 @@ sub indentString($$)
   join "\n", map {$indent.$_} split "\n", $string
  }
 
+#-------------------------------------------------------------------------------
+# Load an array from lines of text in a striung
+#-------------------------------------------------------------------------------
+
+sub loadArrayFromLines($)
+ {my ($string) = @_;                                                            # The string of lines from which to create an array
+  [split "\n", $string]
+ }
+
 #-------------------------------------------------------------------------------
 # Load a hash: first word of each line is the key and the rest is the value
 #-------------------------------------------------------------------------------
@@ -270,6 +279,25 @@ sub loadHashFromLines($)
   +{map{split /\s+/, $_, 2} split "\n", $string}
  }
 
+#-------------------------------------------------------------------------------
+# Load an array of arrays from lines of text: each line is an array of words
+#-------------------------------------------------------------------------------
+
+sub loadArrayArrayFromLines($)
+ {my ($string) = @_;                                                            # The string of lines from which to create an array of arrays
+  [map{[split /\s+/]} split "\n", $string]
+ }
+
+#-------------------------------------------------------------------------------
+# Load a hash of arrays from lines of text: the first word of each line
+# is the key, the remaining words are the array contents
+#-------------------------------------------------------------------------------
+
+sub loadHashArrayFromLines($)
+ {my ($string) = @_;                                                            # The string of lines from which to create a hash of arrays
+  +{map{my @a = split /\s+/; (shift @a, [@a])} split "\n", $string}
+ }
+
 #-------------------------------------------------------------------------------
 # Normalize white space
 #-------------------------------------------------------------------------------
@@ -331,11 +359,13 @@ use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION);
 @ISA          = qw(Exporter);
 @EXPORT       = qw(formatTable);
 @EXPORT_OK    = qw(checkKeys dateStamp dateTimeStamp fileList fileSize
-indentString loadHashFromLines makePath normalizeWhiteSpace
+indentString
+loadArrayArrayFromLines loadArrayFromLines  loadHashArrayFromLines loadHashFromLines
+makePath normalizeWhiteSpace
 readBinaryFile readFile timeStamp writeBinaryFile writeFile);
 %EXPORT_TAGS  = (all=>[@EXPORT_OK]);
 
-$VERSION = '1.003'; # Wednesday 14 December 2016
+$VERSION = '1.004'; # Wednesday 14 December 2016
 
 1;
 
@@ -441,7 +471,7 @@ modified under the same terms as Perl itself.
 =cut
 
 __DATA__
-use Test::More tests => 21;
+use Test::More tests => 24;
 if (1)                                                                          # Unicode
  {use utf8;
   my $z = "𝝰𝝱𝝲";
@@ -514,10 +544,34 @@ END
   ok $s eq $S;
  }
 
-if (1)                                                                          # H
+if (1)                                                                          # AL
+ {my $s = loadArrayFromLines <<END;
+a a
+b b
+END
+  ok dump($s) eq '["a a", "b b"]';
+ }
+
+if (1)                                                                          # HL
  {my $s = loadHashFromLines <<END;
 a 10 11 12
 b 20 21 22
 END
   ok dump($s) eq '{ a => "10 11 12", b => "20 21 22" }';
  }
+
+if (1)                                                                          # AAL
+ {my $s = loadArrayArrayFromLines <<END;
+A B C
+AA BB CC
+END
+  ok dump($s) eq '[["A", "B", "C"], ["AA", "BB", "CC"]]';
+ }
+
+if (1)                                                                          # HAL
+ {my $s = loadHashArrayFromLines <<END;
+a A B C
+b AA BB CC
+END
+  ok dump($s) eq '{ a => ["A", "B", "C"], b => ["AA", "BB", "CC"] }';
+ }
